@@ -11,10 +11,10 @@ from pillow_heif import register_heif_opener
 
 from duplicate_images.common import path_with_parent
 from duplicate_images.function_types import Results
-from duplicate_images.hash_store import PickleHashStore
+from duplicate_images.hash_store import FileHashStore
 from duplicate_images.image_pair_finder import ImagePairFinder, PairFinderOptions
 from duplicate_images.log import setup_logging
-from duplicate_images.methods import ACTIONS_ON_EQUALITY, IMAGE_HASH_ALGORITHM
+from duplicate_images.methods import ACTIONS_ON_EQUALITY, IMAGE_HASH_ALGORITHM, get_hash_size_kwargs
 from duplicate_images.parse_commandline import parse_command_line
 
 register_heif_opener()
@@ -48,22 +48,23 @@ def get_matches(
         hash_store_path: Optional[Path] = None
 ) -> Results:
     hash_algorithm = IMAGE_HASH_ALGORITHM[algorithm]
+    hash_size_kwargs = get_hash_size_kwargs(hash_algorithm, options.hash_size)
     image_files = sorted(files_in_dirs(root_directories, is_image_file))
     logging.info('%d total files', len(image_files))
     logging.info('Computing image hashes')
 
-    with PickleHashStore.create(hash_store_path) as hash_store:
+    with FileHashStore.create(hash_store_path, algorithm, hash_size_kwargs) as hash_store:
         return ImagePairFinder.create(
-            image_files, hash_algorithm, options=options, hash_store=hash_store
-        ).get_pairs()
+            image_files, hash_algorithm, options=options, hash_store=hash_store,
+
+        ).get_equal_groups()
 
 
 def execute_actions(matches: Results, args: Namespace) -> None:
     action_equal = ACTIONS_ON_EQUALITY[args.on_equal]
-
-    for pair in sorted(matches):
+    for group in sorted(matches):
         try:
-            action_equal(args, pair)
+            action_equal(args, group)
         except FileNotFoundError:
             continue
 
