@@ -37,9 +37,14 @@ def parse_command_line(args: Optional[List[str]] = None) -> Namespace:
     parser.add_argument(
         '--parallel', action='store_true', help='Calculate hashes using all available cores'
     )
-    parser.add_argument(
+    group = parser.add_mutually_exclusive_group()
+    group.add_argument(
         '--slow', action='store_true', help='Use slow (O(N^2)) algorithm'
     )
+    group.add_argument(
+        '--group', action='store_true',
+        help='Handle equal images in a group instead of multiple pairs'
+    )
     parser.add_argument(
         '--progress', action='store_true', help='Show progress bars during processing'
     )
@@ -54,6 +59,6 @@ def parse_command_line(args: Optional[List[str]] = None) -> Namespace:
     )
 
     namespace = parser.parse_args(args)
-    if namespace.on_equal == 'exec' and (namespace.exec is None or len(namespace.exec) == 0):
+    if namespace.on_equal == 'exec' and not namespace.exec:
         parser.error('--exec argument is required')
     return namespace
